==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_PT">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pt.ts--</translatorcomment>
        <translation>Fechando o desenho...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Desenho sem título
Sem Título</translatorcomment>
        <translation>Sem título</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Sem título %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+120"/>
        <source>Loading...</source>
        <translation>Carregando...</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import Error</source>
        <translation>Erro de importação</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Cannot open file</source>
        <translation>Não é possível abrir arquivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Nenhum importador adequado encontrado. Por favor, verifique formato de arquivo e extensão.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Por favor, verifique os seus direitos de acesso, o formato de arquivo e extensão do arquivo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File is empty.</source>
        <translation>O arquivo está vazio.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Opened drawing:</source>
        <translation>Inaugurado desenho:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+92"/>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>read-only</source>
        <translation>Apenas leitura</translation>
    </message>
    <message>
        <location line="+41"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Você deseja salvar as alterações feitas no&lt;br&gt;documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Suas alterações serão perdidas se você não salvá-los.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Novo</translatorcomment>
        <translation>&amp;Novo</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/File/NewFile/ts/NewFile_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>CloseDialog</name>
    <message>
        <location filename="../CloseDialog.ui" line="+14"/>
        <source>Closing Drawing...</source>
        <translatorcomment>--ignored ...--
--file: qcadguiqt_pt.ts--</translatorcomment>
        <translation>Encerrando o Desenho...</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../MdiChildEmpty.ui" line="+20"/>
        <source>Untitled</source>
        <translatorcomment>--exact match--
--file: pt_PT.po--
Desenho sem título
Sem Título</translatorcomment>
        <translation>Sem título</translation>
    </message>
</context>
<context>
    <name>NewFile</name>
    <message>
        <source>Untitled %1 [*]</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Sem título %1 [*]</translation>
    </message>
    <message>
        <location filename="../NewFile.js" line="+114"/>
        <source>Opening drawing:</source>
        <translation>Abrindo o desenho:</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="vanished">Carregando...</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Import Error</source>
        <translation>Erro de Importação</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Cannot open file</source>
        <translation>Não é possível abrir o arquivo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>No suitable Importer found. Please check file format and extension.</source>
        <translation>Nenhum importador adequado foi encontrado. Por favor, verifique o formato do arquivo e a extensão.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>File not found.</source>
        <translation>Arquivo não encontrado.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Please check your access rights, the file format and file extension.</source>
        <translation>Por favor, verifique os seus direitos de acesso, o formato do arquivo e a extensão do arquivo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Import failed.</source>
        <translation>Importação falhou.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>File is empty.</source>
        <translation>O arquivo está vazio.</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Drawing loaded successfully:</source>
        <translation>Desenho carregado com sucesso:</translation>
    </message>
    <message>
        <source>Opened drawing:</source>
        <translation type="vanished">Aberto o Desenho:</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Format:</source>
        <translation>Formato:</translation>
    </message>
    <message>
        <location line="+124"/>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>read-only</source>
        <translation>apenas leitura</translation>
    </message>
    <message>
        <location line="+53"/>
        <source>Do you want to save the changes you made in&lt;br&gt;the document &apos;%1&apos;?</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Você deseja gravar as alterações feitas no&lt;br&gt;do documento &apos;%1&apos;?</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Suas alterações serão perdidas se você não gravá-las.</translation>
    </message>
    <message>
        <location filename="../NewFileInit.js" line="+2"/>
        <source>&amp;New</source>
        <translatorcomment>--exact match--
--file: qcadactions_pt.ts--
&amp;Novo</translatorcomment>
        <translation>&amp;Novo</translation>
    </message>
</context>
</TS>
